'use client'

import Link from 'next/link'
import { useRouter } from 'next/navigation'
import { useEffect, useState } from 'react'

import Cookies from 'js-cookie'

import Spinner from '@/components/ui/Spinner'
import { Button } from '@/components/ui/button'
import axiosClient from '@/services/axiosClient'
import { useCheckoutStore } from '@/store/checkout'

export default function Page({ searchParams = {} }: { searchParams: any }) {
  const router = useRouter()
  const token = Cookies.get('siamoods_token')
  const [isLoading, setIsLoading] = useState(true)
  const setCheckoutStore = useCheckoutStore((state) => state.setCheckoutStore)
  const [isError, setIsError] = useState(false)

  const handleCheckout = async () => {
    const paymentMethod = localStorage.getItem('payment_method')
    const totalPrice = localStorage.getItem('totalPrice')
    const cartItemsIds = JSON.parse(
      localStorage.getItem('cartItemsIds') || '[]'
    )

    if (paymentMethod) {
      try {
        const res = await axiosClient.post('api/orders/payments/success', {
          payment_method: paymentMethod,
          ...searchParams,
        })

        if (localStorage.getItem('isGiftCardPurchase') === 'true') {
          localStorage.removeItem('isGiftCardPurchase')
          router.push('/')
          return
        }
        if (process.env.NODE_ENV === 'production') {
          fbq('track', 'Purchase', {
            content_ids: cartItemsIds,
            currency: 'AMD',
            value: totalPrice,
            content_type: 'product',
          })
          gtag('event', 'purchase', {
            value: totalPrice,
            currency: 'AMD',
            items: cartItemsIds,
          })
        }

        const orderId = res.data.order_id
        if (orderId) {
          setCheckoutStore('navigatedFromCheckout', '1')
          if (token) {
            router.push(`/orders/${orderId}`)
          } else {
            router.push(`/guest-orders/${orderId}`)
          }
        }
      } catch (error) {
        setIsError(true)
      } finally {
        setIsLoading(false)
        localStorage.removeItem('payment_method')
        localStorage.removeItem('totalPrice')
        localStorage.removeItem('cartItemsIds')
      }
    }
  }

  useEffect(() => {
    handleCheckout()
  }, [])

  return (
    <div className='fixed inset-0 z-30 bg-white'>
      {isError ? (
        <div className='absolute left-1/2 top-1/2 flex -translate-x-1/2 translate-y-[calc(-50%-4rem)] flex-col items-center justify-center gap-4 text-gray-800'>
          <h1 className='text-6xl font-bold'>404</h1>
          <p className='text-2xl'>
            Վճարումը տեղի չի ունեցել խնդրում ենք փորձել մի փոքր ուշ
          </p>
          <Link href='/'>
            <Button>Վերադառնալ գլխավոր էջ</Button>
          </Link>
        </div>
      ) : (
        <>
          <Spinner isSpinning={isLoading} />
          <h1 className='absolute left-1/2 top-1/2 -translate-x-1/2 translate-y-[calc(-50%-8rem)] text-2xl font-bold text-muted-foreground'>
            Խնդրում ենք սպասել
          </h1>
        </>
      )}
    </div>
  )
}
