import { Suspense } from 'react'

import {
  HydrationBoundary,
  QueryClient,
  dehydrate,
} from '@tanstack/react-query'

import ProfileAndPay from '@/components/ProfileAndPay'
import axiosServer from '@/services/axiosServer'
import { User } from '@/types/profile.type'

import Delivery from './Delivery'
import PromoCodeOrGiftCart from './PromoCodeOrGiftCart'

export const dynamic = 'force-dynamic'

export default async function CheckoutLayout({
  children,
}: Readonly<{
  children: React.ReactNode
}>) {
  const queryClient = new QueryClient()
  await queryClient.prefetchQuery({
    queryKey: ['account'],
    queryFn: async (): Promise<User | undefined> => {
      const res = await axiosServer('api/account')
      return res.data.data
    },
  })
  // await queryClient.prefetchQuery({
  //   queryKey: ['shipping'],
  //   queryFn: async (): Promise<any | undefined> => {
  //     const res = await axiosServer('api/shipping')
  //     return res.data
  //   },
  // })

  return (
    <HydrationBoundary state={dehydrate(queryClient)}>
      <div className='container pb-8'>
        <h1 className='text-xl'>Առաքման եղանակներ</h1>
        <div className='flex items-start gap-8 pt-8 md:flex-col'>
          <div className='flex flex-1 flex-col gap-4'>
            <Suspense fallback={<div>Loading...</div>}>
              <Delivery />
            </Suspense>
            {children}
            <Suspense fallback={<div>Loading...</div>}>
              <ProfileAndPay isInPayment={true} />
            </Suspense>
          </div>
          <PromoCodeOrGiftCart />
        </div>
      </div>
    </HydrationBoundary>
  )
}
