'use client'

import ProductCard from '@/components/cards/ProductCard'
import { useToast } from '@/components/ui/use-toast'
import { getFavorites } from '@/server/getFavorites'
import axiosClient from '@/services/axiosClient'
import { useUserStore } from '@/store/user'
import { useMutation, useQuery, useQueryClient } from '@tanstack/react-query'
import { AxiosError } from 'axios'
import RemoveProduct from './RemoveProduct'

export default function Favorites() {
  const queryClient = useQueryClient()
  const { addOrRemoveFavorite } = useUserStore()
  const { toast } = useToast()
  const { data } = useQuery({
    queryKey: ['favorites'],
    queryFn: getFavorites,
    staleTime: 1000 * 60 * 60,
  })

  const mutation = useMutation({
    mutationFn: (id: number) => {
      return axiosClient.delete(`api/remove-favorite/${id}`)
    },
    onSuccess: (_, variables) => {
      const id = variables
      queryClient.invalidateQueries({ queryKey: ['favorites'] })
      addOrRemoveFavorite(id)
      toast({
        title: 'Ապրանքը հեռացված է',
      })
    },
    onError: (error) => {
      if (error instanceof AxiosError) {
        if (error?.response?.data.message) {
          toast({
            title: error.response.data.message,
            variant: 'destructive',
          })
        }
      }
    },
  })

  return (
    <div>
      {data?.length === 0 ? (
        <div className='mt-4 space-y-4 rounded-lg bg-muted p-12 text-center text-lg text-muted-foreground'>
          <h2> Դուք չունեք նախընտրած ապրանքներ</h2>
        </div>
      ) : (
        <div className='grid grid-cols-3 lg:grid-cols-2 sm:grid-cols-1'>
          {data?.map((item) => (
            <div key={item.haysell_id} className='flex flex-col items-center'>
              <RemoveProduct onClick={() => mutation.mutate(item.haysell_id)} />
              <ProductCard product={item} />
            </div>
          ))}
        </div>
      )}
    </div>
  )
}
