'use client'

import { Button } from '@/components/ui/button'
import { useToast } from '@/components/ui/use-toast'
import { getFavorites } from '@/server/getFavorites'
import axiosClient from '@/services/axiosClient'
import { useUserStore } from '@/store/user'
import { useMutation, useQuery, useQueryClient } from '@tanstack/react-query'
import { AxiosError } from 'axios'

function RemoveAll() {
  const queryClient = useQueryClient()
  const { toast } = useToast()
  const { removeAllFavorites } = useUserStore()

  const { data } = useQuery({
    queryKey: ['favorites'],
    queryFn: getFavorites,
    staleTime: 1000 * 60 * 60,
  })

  const mutation = useMutation({
    mutationFn: () => axiosClient.post('api/clear-favorites'),
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ['favorites'] })
      removeAllFavorites()
      toast({
        title: 'Բոլոր ապրանքները հեռացված են',
      })
    },
    onError: (error) => {
      if (error instanceof AxiosError) {
        if (error?.response?.data.message) {
          toast({
            title: error.response.data.message,
            variant: 'destructive',
          })
        }
      }
    },
  })

  return (
    <Button
      onClick={() => mutation.mutate()}
      disabled={mutation.isPending || !data || (data && data.length === 0)}
    >
      Դատարկել ցանկը
    </Button>
  )
}

export default RemoveAll
