import { Metadata } from 'next'
import { notFound } from 'next/navigation'

import {
  HydrationBoundary,
  QueryClient,
  dehydrate,
} from '@tanstack/react-query'

import axiosServer from '@/services/axiosServer'
import { User } from '@/types/profile.type'
import { SeoMeta } from '@/types/store.type'

import DigitalGiftCard from './DigitalGiftCard'

export async function generateMetadata(): Promise<Metadata> {
  const res = await axiosServer('api/get-static-metas/digital_gift_card')
  const seo: SeoMeta = res.data.data

  if (!seo) return notFound()

  return {
    title: seo.meta_title,
    description: seo.meta_description,
    keywords: seo.meta_keywords,
    publisher: 'SiaMoods',
    category: 'website',
    openGraph: {
      images: '/images/logo.png',
      title: seo.meta_title,
      description: seo.meta_description,
      type: 'website',
      siteName: 'SiaMoods',
      url: `${process.env.NEXT_PUBLIC_APP_URL}digital-gift-card`,
    },
    alternates: {
      canonical: `${process.env.NEXT_PUBLIC_APP_URL}digital-gift-card`,
    },
  }
}

export default async function page() {
  const queryClient = new QueryClient()
  await queryClient.prefetchQuery({
    queryKey: ['account'],
    queryFn: async (): Promise<User | undefined> => {
      const res = await axiosServer('api/account')
      return res.data.data
    },
  })

  return (
    <HydrationBoundary state={dehydrate(queryClient)}>
      <div>
        <DigitalGiftCard />
      </div>
    </HydrationBoundary>
  )
}
