'use client'

import { Button, buttonVariants } from '@/components/ui/button'
import {
  Form,
  FormControl,
  FormField,
  FormItem,
  FormLabel,
  FormMessage,
} from '@/components/ui/form'
import { Input } from '@/components/ui/input'
import { useToast } from '@/components/ui/use-toast'
import axiosClient from '@/services/axiosClient'
import { zodResolver } from '@hookform/resolvers/zod'
import Link from 'next/link'
import { useForm } from 'react-hook-form'
import * as z from 'zod'

const formSchema = z.object({
  email: z.string().min(1, { message: 'Էլ․ հասցեն պարտադիր է' }).email({
    message: 'Խնդրում ենք մուտքագրել վավեր էլ․ հասցե',
  }),
})

export default function ForgotPassword() {
  const { toast } = useToast()
  const form = useForm({
    resolver: zodResolver(formSchema),
    defaultValues: {
      email: '',
    },
  })

  async function onSubmit(values: z.infer<typeof formSchema>) {
    try {
      await axiosClient.post('api/forgot-password', {
        email: values.email,
        api_reset: 1,
      })
      toast({
        title: 'Վերականգնման հասցեն ուղարկված է',
      })
    } catch (error) {
      toast({
        title: 'Ինչ որ բան այնպես չէ',
        variant: 'destructive',
      })
    }
  }

  return (
    <div className='flex h-96 items-center justify-center'>
      <div className='flex w-full max-w-md flex-col items-center gap-8 rounded-xl p-8 shadow-xl'>
        <h1 className='text-lg'>Գաղտնաբառի վերականգնում</h1>
        <Form {...form}>
          <form
            onSubmit={form.handleSubmit(onSubmit)}
            className='flex w-full flex-col items-center gap-4'
          >
            <FormField
              name='email'
              render={({ field }) => (
                <FormItem>
                  <FormLabel required={true}>էլ․ հասցե</FormLabel>
                  <FormControl>
                    <Input {...field} type='email' />
                  </FormControl>
                  <FormMessage />
                </FormItem>
              )}
            />
            <div className='flex w-full justify-between'>
              <Link
                href='/login'
                className={buttonVariants({
                  variant: 'ghost',
                })}
              >
                Մուտք
              </Link>
              <Button>Վերականգնել</Button>
            </div>
          </form>
        </Form>
      </div>
    </div>
  )
}
