import { Metadata } from 'next'
import { notFound } from 'next/navigation'

import {
  HydrationBoundary,
  QueryClient,
  dehydrate,
} from '@tanstack/react-query'

import ProductCard from '@/components/cards/ProductCard'
import { getGiftCards } from '@/server/getGiftCards'
import axiosServer from '@/services/axiosServer'
import { ProductType } from '@/types'
import { SeoMeta } from '@/types/store.type'

export const dynamic = 'force-dynamic'

export async function generateMetadata(): Promise<Metadata> {
  const res = await axiosServer('api/get-static-metas/gift_card')
  const seo: SeoMeta = res.data.data

  if (!seo) return notFound()

  return {
    title: seo.meta_title,
    description: seo.meta_description,
    keywords: seo.meta_keywords,
    publisher: 'SiaMoods',
    category: 'website',
    openGraph: {
      images: '/images/logo.png',
      title: seo.meta_title,
      description: seo.meta_description,
      type: 'website',
      siteName: 'SiaMoods',
      url: `${process.env.NEXT_PUBLIC_APP_URL}gift-card`,
    },
    alternates: {
      canonical: `${process.env.NEXT_PUBLIC_APP_URL}gift-card`,
    },
  }
}

export default async function page() {
  const queryClient = new QueryClient()
  await queryClient.prefetchQuery({
    queryKey: ['gift-cards'],
    queryFn: getGiftCards,
  })
  const giftCards = queryClient.getQueryData<ProductType[]>(['gift-cards'])

  return (
    <HydrationBoundary state={dehydrate(queryClient)}>
      <div className='container flex flex-col items-center gap-4 p-12 pt-0 md:px-4'>
        <div className='relative isolate flex w-full max-w-96 justify-center'>
          <h1 className='bg-background px-8 text-2xl text-primary sm:text-xl'>
            Նվեր Քարտ
          </h1>
          <div className='absolute top-1/2 -z-10 h-px w-full  translate-y-1/2 bg-primary' />
        </div>
        <div className='grid grid-cols-4 gap-4 lg:grid-cols-2 sm:grid-cols-1'>
          {giftCards?.map((product) => (
            <ProductCard key={product.haysell_id} product={product} />
          ))}
        </div>
      </div>
    </HydrationBoundary>
  )
}
