import { SliderRange } from '@/components/ui/SliderRange'
import { cleanObject } from '@/lib/utils'
import { getProducts } from '@/server/getProducts'
import { getStoreData } from '@/server/getStore'
// import { getStoreData } from '@/server/getStore'
import { keepPreviousData, useQuery } from '@tanstack/react-query'
import { useParams, useSearchParams } from 'next/navigation'

export default function FilterPriceForSubStore() {
  const slug = useParams().slug

  const { data: storeData } = useQuery({
    queryKey: ['store'],
    queryFn: getStoreData,
    staleTime: 1000 * 60 * 60,
  })

  let type = undefined
  if (slug && slug?.length > 0) {
    type = storeData?.types.find((type) => type.slug === slug[0])?.id.toString()
  }

  let subType = undefined
  if (slug && slug?.length > 1) {
    subType = storeData?.types
      .flatMap((type) => type.subTypes)
      .find((subType) => subType.slug === slug[1])
      ?.id.toString()
  }

  const searchParams = useSearchParams()
  const keys = cleanObject({
    page: searchParams.get('page') || '1',
    type: subType ? null : type,
    sub_type: subType,
  })
  const { data: productsData } = useQuery({
    queryKey: ['products', keys],
    queryFn: () =>
      getProducts({
        searchParams,
        typeParam: subType ? undefined : [type || ''],
        subTypeParam: [subType || ''],
      }),
    staleTime: 1000 * 60 * 60,
    placeholderData: keepPreviousData,
  })

  const min = productsData?.minPrice ?? 100
  const max = productsData?.maxPrice ?? 50000

  return <SliderRange min={min} max={max} step={100} />
}
