'use client'

import Autoplay from 'embla-carousel-autoplay'

import {
  Carousel,
  CarouselContent,
  CarouselDots,
  CarouselItem,
} from '@/components/ui/carousel'
import { cn } from '@/lib/utils'
import type { ProductType } from '@/types'

import CardCarouselTitle from './CardCarouselTitle'
import ProductCard from './cards/ProductCard'

const CardCarousel = ({
  title,
  href = '/',
  products,
  showDots = true,
  containerClassName,
  isInProduct = false,
  isAutoPlay = true,
  alwaysShowButtons = false,
}: {
  title?: string
  href?: string
  products: ProductType[]
  showDots?: boolean
  containerClassName?: string
  isInProduct?: boolean
  isAutoPlay?: boolean
  alwaysShowButtons?: boolean
}) => {
  if (!products.length) return null

  const plugins = isAutoPlay ? [Autoplay({ delay: 3000 })] : []

  return (
    <div className={cn('pt-8', containerClassName)}>
      {title && <CardCarouselTitle title={title} href={href} />}
      <Carousel
        opts={{
          align: 'start',
        }}
        plugins={plugins}
        className={cn(
          'container px-0',
          isInProduct && 'max-w-[600px] sm:max-w-[100vw]'
        )}
      >
        <CarouselContent>
          {/* <CarouselContent className={cn(isInProduct && '-ml-0')}> */}
          {products.map((item) => (
            <CarouselItem
              key={item.haysell_id}
              //  className='pl-0'
              className={cn(
                ' sm:basis-full',
                // isInProduct
                //   ? 'basis-1/3 pl-0 lg:basis-1/2'
                //   :
                'basis-1/4 lg:basis-1/3 md:basis-1/2'
              )}
            >
              <ProductCard
                className={cn('mx-2 ', isInProduct ? 'mb-2' : 'mb-8')}
                product={item}
                isInProduct={isInProduct}
                alwaysShowButtons={alwaysShowButtons}
              />
            </CarouselItem>
          ))}
        </CarouselContent>
        {showDots && <CarouselDots className='mt-0' buttonClassName='size-3' />}
      </Carousel>
    </div>
  )
}

export default CardCarousel
