'use client'

import { useState } from 'react'

import { AxiosError } from 'axios'
import ReCAPTCHA from 'react-google-recaptcha'

import { Button } from '@/components/ui/button'
import {
  Dialog,
  DialogContent,
  DialogHeader,
  DialogTrigger,
} from '@/components/ui/dialog'
import { Input } from '@/components/ui/input'
import { useToast } from '@/components/ui/use-toast'
import axiosClient from '@/services/axiosClient'

const Subscribe = () => {
  const { toast } = useToast()
  const [email, setEmail] = useState('')
  const [open, setOpen] = useState(false)
  const [loading, setLoading] = useState(false)

  async function handleSubscribe(captchaToken: string) {
    setLoading(true)
    try {
      await axiosClient.post('api/subscribe', { email, captchaToken })
      setEmail('')
      toast({
        title: 'Դուք հաջողությամբ բաժանորդագրվել եք',
      })
    } catch (error) {
      if (error instanceof AxiosError) {
        if (error?.response?.data.errors) {
          const message = Object.values(error.response.data.errors)[0] as string
          toast({
            title: message,
            variant: 'destructive',
          })
        }
      }
    }
    setOpen(false)
    setLoading(false)
  }
  return (
    <div className='flex flex-col items-center gap-6'>
      <h3 className='spacin text-center font-bold [word-spacing:0.4rem]'>
        ԲԱԺԱՆՈՐԴԱԳՐՎԵԼ ՄԵՐ ՆՈՐՈՒԹՅՈՒՆՆԵՐԻՆ
      </h3>
      <div className='relative w-full'>
        <Input
          className='pr-32'
          type='email'
          value={email}
          placeholder='Էլ․ հասցե'
          onKeyDown={(e) => {
            if (e.key === 'Enter' && email && !loading) {
              setOpen(true)
            }
          }}
          onChange={(e) => setEmail(e.target.value)}
        />

        <Dialog open={open} onOpenChange={setOpen} modal={false}>
          <DialogTrigger asChild>
            <Button
              className='absolute right-0 top-1/2 h-full -translate-y-1/2 rounded-l-none border-l-0 disabled:opacity-100'
              disabled={loading || !email}
            >
              ՀԱՍՏԱՏԵԼ
            </Button>
          </DialogTrigger>
          {open && (
            <div
              className='fixed inset-0 z-20 bg-black/50'
              onClick={() => setOpen(false)}
            />
          )}
          <DialogContent className='p-0'>
            <DialogHeader className='bg-muted p-4 text-start text-muted-foreground'>
              <h2>ԲԱԺԱՆՈՐԴԱԳՐՎԵԼ ՄԵՐ ՆՈՐՈՒԹՅՈՒՆՆԵՐԻՆ</h2>
            </DialogHeader>
            <div className='flex h-48 items-center justify-center pb-4'>
              <ReCAPTCHA
                sitekey={process.env.NEXT_PUBLIC_RE_CAPTCHA_KEY as string}
                onChange={(token) => {
                  if (token) {
                    handleSubscribe(token)
                  }
                }}
              />
            </div>
          </DialogContent>
        </Dialog>
      </div>
    </div>
  )
}

export default Subscribe
