import { Button } from '@/components/ui/button'
import {
  Dialog,
  DialogContent,
  DialogHeader,
  DialogTrigger,
} from '@/components/ui/dialog'
import { Eye } from 'lucide-react'
import Product from '../Product'
import { useUserStore } from '@/store/user'

const ViewProductDialog = ({
  haysellId,
  slug,
}: {
  haysellId: number
  slug: string
}) => {
  const selectedViewProductDialog = useUserStore(
    (state) => state.selectedViewProductDialog
  )
  const setSelectedViewProductDialog = useUserStore(
    (state) => state.setSelectedViewProductDialog
  )

  return (
    <Dialog
      open={selectedViewProductDialog === haysellId}
      onOpenChange={(open) => {
        if (open) {
          setSelectedViewProductDialog(haysellId)
        } else {
          setSelectedViewProductDialog(undefined)
        }
      }}
    >
      <DialogTrigger asChild>
        <Button variant='ghost' size='iconSm'>
          <Eye size={20} />
        </Button>
      </DialogTrigger>
      <DialogContent className='max-h-dvh gap-0 overflow-y-auto p-0'>
        <DialogHeader className='bg-muted p-4 text-start text-muted-foreground'>
          <h2>Ապրանքի դիտում</h2>
        </DialogHeader>
        <Product isInDialog={true} slug={slug} className='p-4 pb-8' />
      </DialogContent>
    </Dialog>
  )
}

export default ViewProductDialog
