'use client'

import { useSearchParams } from 'next/navigation'
import { useEffect, useState } from 'react'

// import { useUserStore } from '@/store/user'
import { Search } from 'lucide-react'
import { useRouter } from 'next-nprogress-bar'

import { Button } from '@/components/ui/button'
import { Input } from '@/components/ui/input'
import { cn } from '@/lib/utils'

const GlobalSearch = ({ className }: { className?: string }) => {
  const router = useRouter()
  const searchParams = useSearchParams()
  const globalSearch = searchParams.get('search') || ''
  const [search, setSearch] = useState(globalSearch)

  const handleSearch = () => {
    if (search) {
      const params = new URLSearchParams()
      params.append('search', search)
      router.push(`/store?${params.toString()}`)

      // Programmatically trigger the Escape for closing the mobile menu
      const escEvent = new KeyboardEvent('keydown', { key: 'Escape' })
      document.dispatchEvent(escEvent)
    }
  }

  useEffect(() => {
    setSearch(globalSearch)
  }, [globalSearch])

  return (
    <div className={cn('relative', className)}>
      <Input
        className='max-w-52 pr-10 md:max-w-full'
        placeholder='Որոնել'
        value={search}
        onChange={(e) => setSearch(e.target.value)}
        onKeyDown={(e) => {
          if (e.key === 'Enter') {
            handleSearch()
          }
        }}
      />
      <Button
        variant='outline'
        size='iconSm'
        className='absolute right-0 top-1/2 h-full -translate-y-1/2 rounded-l-none border-l-0 bg-background'
        onClick={handleSearch}
      >
        <Search className='text-muted-foreground' />
      </Button>
    </div>
  )
}

export default GlobalSearch
