import { Button } from '@/components/ui/button'
import { Calendar } from '@/components/ui/calendar'
import {
  Popover,
  PopoverContent,
  PopoverTrigger,
} from '@/components/ui/popover'
import { cn } from '@/lib/utils'
import { format } from 'date-fns'
import { CalendarIcon } from 'lucide-react'
import { useState } from 'react'

export function DatePicker({
  value,
  setValue,
}: {
  value?: string
  setValue: (date: string | undefined) => void
}) {
  const [isCalendarOpen, setIsCalendarOpen] = useState(false)

  return (
    <Popover open={isCalendarOpen} onOpenChange={setIsCalendarOpen}>
      <PopoverTrigger asChild>
        <Button
          variant={'ghost'}
          className={cn(
            'w-full justify-start border text-left font-normal',
            !value && 'text-muted-foreground'
          )}
        >
          <CalendarIcon className='mr-2 h-4 w-4' />
          {value ? format(value, 'MM/dd/yyyy') : <span>Pick a date</span>}
        </Button>
      </PopoverTrigger>
      <PopoverContent align='start' className=' w-auto p-0'>
        <Calendar
          mode='single'
          captionLayout='dropdown-buttons'
          selected={value ? new Date(value) : undefined}
          onDayClick={(e) => {
            if (e) {
              const formattedDate = format(e, 'yyyy-MM-dd')
              setValue(formattedDate)
              setIsCalendarOpen(false)
            }
          }}
          fromYear={1960}
          toYear={2030}
        />
        <div className='flex justify-between p-2 pt-0 text-muted-foreground'>
          <Button
            variant='ghost'
            className='h-8 font-normal'
            onClick={() => {
              setValue(undefined)
              setIsCalendarOpen(false)
            }}
          >
            Clear
          </Button>
          <Button
            variant='ghost'
            className='h-8 font-normal'
            onClick={() => {
              setValue(format(new Date(), 'yyyy-MM-dd'))
              setIsCalendarOpen(false)
            }}
          >
            Today
          </Button>
        </div>
      </PopoverContent>
    </Popover>
  )
}
