/* eslint-disable */
const axios = require('axios')
const fs = require('fs')
const path = require('path')
const cron = require('node-cron')

async function updateSitemap() {
  console.log(`[${new Date().toISOString()}] Starting sitemap update`)

  try {
    const outputPath = path.join(process.cwd(), 'app', 'sitemap.xml')

    // Make the API request
    const response = await axios.get('https://admin.siamoods.com/api/sitemap', {
      timeout: 10000,
    })

    // Write to temporary file first
    const tempFile = `${outputPath}.temp`
    fs.writeFileSync(tempFile, response.data)

    // Rename temp file to actual file (atomic operation)
    fs.renameSync(tempFile, outputPath)

    console.log(`[${new Date().toISOString()}] Sitemap updated successfully`)
  } catch (error) {
    console.error(`[${new Date().toISOString()}] Error updating sitemap:`, {
      message: error.message,
      code: error.code,
      response: error.response?.status,
    })
  }
}

function createSitemapTask(schedule = '0 0 * * *') {
  // Create the cron job
  const task = cron.schedule(schedule, updateSitemap, {
    scheduled: true,
    timezone: 'UTC',
  })

  console.log(
    `[${new Date().toISOString()}] Sitemap updater scheduled with pattern: ${schedule}`
  )

  // Run immediately on start
  updateSitemap()

  return task
}

module.exports = createSitemapTask
