import * as z from 'zod'

export default z
  .object({
    email: z.string().min(1, { message: 'Էլ․ հասցեն պարտադիր է' }).email({
      message: 'Խնդրում ենք մուտքագրել վավեր էլ․ հասցե',
    }),

    profileFirstName: z.string().optional(),
    profileLastName: z.string().optional(),
    profilePhone: z.string().optional(),
    subscribe: z.boolean(),

    firstName: z.string().min(1, { message: 'Անունը պարտադիր է' }),
    lastName: z.string().min(1, { message: 'Ազգանունը պարտադիր է' }),

    address: z.string().min(1, { message: 'Հասցեն պարտադիր է' }),
    cityOrVillage: z
      .string()
      .min(1, { message: 'Քաղաքը կամ գյուղը պարտադիր է' }),
    state: z.string().min(1, { message: 'Մարզը պարտադիր է' }),
    phone: z.string().length(8, { message: 'Հեռախոսը պարտադիր է' }),
    zip: z.string().length(4, { message: 'Փ. ինդեքսը պարտադիր է' }),
    note: z.string().optional(),

    payerAddressIfDifferent: z.boolean(),

    payerFirstName: z.string().optional(),
    payerLastName: z.string().optional(),
    payerAddress: z.string().optional(),
    payerCityOrVillage: z.string().optional(),
    payerState: z.string().optional(),
    payerPhone: z.string().optional(),
    payerZip: z.string().optional(),
  })
  .superRefine(
    (
      {
        payerAddressIfDifferent,
        payerFirstName,
        payerLastName,
        payerAddress,
        payerCityOrVillage,
        payerState,
        payerPhone,
        payerZip,
      },
      refinementContext
    ) => {
      if (payerAddressIfDifferent) {
        const issues = []
        if (!payerFirstName) {
          issues.push({
            code: z.ZodIssueCode.custom,
            message: 'Անունը պարտադիր է',
            path: ['payerFirstName'],
          })
        }
        if (!payerLastName) {
          issues.push({
            code: z.ZodIssueCode.custom,
            message: 'Ազգանունը պարտադիր է',
            path: ['payerLastName'],
          })
        }
        if (!payerAddress) {
          issues.push({
            code: z.ZodIssueCode.custom,
            message: 'Հասցեն պարտադիր է',
            path: ['payerAddress'],
          })
        }
        if (!payerCityOrVillage) {
          issues.push({
            code: z.ZodIssueCode.custom,
            message: 'Քաղաքը կամ գյուղը պարտադիր է',
            path: ['payerCityOrVillage'],
          })
        }
        if (!payerState) {
          issues.push({
            code: z.ZodIssueCode.custom,
            message: 'Մարզը պարտադիր է',
            path: ['payerState'],
          })
        }
        if (!payerPhone || payerPhone.length !== 8) {
          issues.push({
            code: z.ZodIssueCode.custom,
            message: 'Հեռախոսը պարտադիր է',
            path: ['payerPhone'],
          })
        }
        if (payerZip && payerZip.length !== 4) {
          issues.push({
            code: z.ZodIssueCode.custom,
            message: 'Փ. ինդեքսը սխալ է',
            path: ['payerZip'],
          })
        }
        for (let issue of issues) {
          refinementContext.addIssue(issue)
        }
      }
    }
  )
