import { ReadonlyURLSearchParams } from 'next/navigation'

import { AxiosError } from 'axios'

import axiosClient from '@/services/axiosClient'
import { ProductType } from '@/types'

// $type = $request->type;
// $subType = $request->sub_type;
// $stone = $request->stone;
// $collection = $request->filter;
// $discount = $request->discount;
// $balance = $request->balance;
// $sort_by = $request->sort_by;
// $search = $request->search;
// $min_price = $request->min_price;
// $max_price = $request->max_price;

export async function getProducts({
  searchParams,
  typeParam,
  subTypeParam,
}: {
  searchParams: ReadonlyURLSearchParams
  typeParam?: string[]
  subTypeParam?: string[]
}): Promise<
  | {
      data: ProductType[]
      minPrice: number
      maxPrice: number
      meta: {
        current_page: number
        last_page: number
      }
    }
  | undefined
> {
  try {
    const page = searchParams.get('page') || '1'
    const stone = searchParams.get('stone')?.split(',')
    const type = typeParam ? typeParam : searchParams.get('type')?.split(',')
    const filter = searchParams.get('filter')?.split(',')
    const sub_type = subTypeParam
      ? subTypeParam
      : searchParams.get('sub_type')?.split(',')
    const balance = searchParams.get('balance')
    const discount = searchParams.get('discount')
    const sort_by = searchParams.get('sort_by')
    const search = searchParams.get('search')
    const min_price = searchParams.get('min_price')
    const max_price = searchParams.get('max_price')

    const res = await axiosClient('api/products', {
      params: {
        page,
        balance,
        discount,
        stone,
        type,
        filter,
        sub_type,
        sort_by,
        search,
        min_price,
        max_price,
      },
    })
    if (!res.data) throw new Error('No data')
    return res.data
  } catch (error) {
    if (error instanceof AxiosError) {
      console.log(error)
    }
  }
}
