import axios, { AxiosError, AxiosResponse } from 'axios'
import { cookies } from 'next/headers'

const axiosServer = axios.create({
  baseURL: process.env.NEXT_PUBLIC_API_URL,
})

axiosServer.interceptors.request.use((config) => {
  const token = cookies().get('siamoods_token')?.value
  config.headers.Authorization = token ? `Bearer ${token}` : ''
  return config
})

axiosServer.interceptors.response.use(
  (response: AxiosResponse) => {
    // Any status code that lie withain the range of 2xx cause this function to trigger
    // Do something with response data
    return response
  },
  (error: AxiosError) => {
    // Any status codes that falls outside the range of 2xx cause this function to trigger
    // Do something with response error
    if (error.response && error.response.status === 401) {
      // Handle 401 error here
      cookies().delete('siamoods_token')
    }
    return Promise.reject(error)
  }
)

export default axiosServer
