import { create } from 'zustand'

interface UserState {
  skipAuthCheck: boolean
  setSkipAuthCheck: (skipAuthCheck: boolean) => void

  selectedViewProductDialog: number | undefined
  setSelectedViewProductDialog: (id: number | undefined) => void
  currentAddedProductDialog: number | undefined
  setCurrentAddedProductDialog: (id: number | undefined) => void

  currentBreadcrumbItem: { slug: string; name: string }
  setCurrentBreadcrumbItem: (slug: string, name: string) => void

  currentFavorites: { haysell_id: number; isFavorite: boolean }[]
  addOrRemoveFavorite: (id: number) => void
  addFavorite: (id: number) => void
  removeAllFavorites: () => void
}

export const useUserStore = create<UserState>()((set) => ({
  skipAuthCheck: false,
  setSkipAuthCheck: (skipAuthCheck) => set({ skipAuthCheck }),

  selectedViewProductDialog: undefined,
  setSelectedViewProductDialog: (id) => set({ selectedViewProductDialog: id }),
  currentAddedProductDialog: undefined,
  setCurrentAddedProductDialog: (id) => set({ currentAddedProductDialog: id }),

  currentBreadcrumbItem: { slug: '', name: '' },
  setCurrentBreadcrumbItem: (slug, name) =>
    set({ currentBreadcrumbItem: { slug, name } }),

  currentFavorites: [],
  addOrRemoveFavorite: (id: number) => {
    set((state) => {
      const index = state.currentFavorites.findIndex(
        (item) => item.haysell_id === id
      )
      if (index !== -1) {
        state.currentFavorites[index].isFavorite =
          !state.currentFavorites[index].isFavorite
        return {
          currentFavorites: state.currentFavorites,
        }
      } else {
        return {
          currentFavorites: [
            ...state.currentFavorites,
            { haysell_id: id, isFavorite: true },
          ],
        }
      }
    })
  },
  // if there is no id add it if there is do nothing
  addFavorite: (id: number) =>
    set((state) => {
      if (!state.currentFavorites.some((item) => item.haysell_id === id)) {
        return {
          currentFavorites: [
            ...state.currentFavorites,
            { haysell_id: id, isFavorite: true },
          ],
        }
      }
      return state
    }),
  removeAllFavorites: () =>
    set((state) => ({
      currentFavorites: state.currentFavorites.map((item) => ({
        ...item,
        isFavorite: false,
      })),
    })),
}))
