export type HomeData = {
  customizations: {
    logo: KeyValue
    copyright: KeyValue
    paymentDelivery: KeyValue[]
    headerData: HeaderData[]
    footerData: HeaderData[]
    social: Social[]
  }
  banners: Banner[]
  discount: ProductType[]
  new: ProductType[]
  liked: ProductType[]
  blog: BlogPostHome[]
}

export type KeyValue = {
  name: string
  value: string | null
}

export type HeaderData = {
  name: string
  href: string
  subItems: HeaderData[]
}

export type Social = {
  icon: string
  url: string
}

export type Banner = {
  image: string
  name: string
  url: string
  new_tab: string
}

export type Variation = {
  id: string
  title: string
  available: number
  price: number
  discount: number
  discount_price: number
}

export type ImageType = {
  image: string
}

export type BlogPostHome = {
  image: string
  title: string
  url: string
  date: string
}

type Review = {
  name: string
  review: string
  rating: number
  date: string
}

export type ProductType = {
  haysell_id: number
  slug: string
  images: ImageType[] | []
  title: string
  url: string
  price: number
  discount: number
  discount_price: number
  discount_left: null | number
  label: null | string
  is_favorite: boolean
  available: number
  variation_type: string
  variations: Variation[]
  specification: string
  description: string
  short_description: string
  meta_title: string
  meta_keywords: string
  meta_description: string
  weight: string
  size: null | string
  reviews: null | Review[]
  linked_title: string
  linked_products: null | ProductType[]
  related_products: null | ProductType[]
}

export type Checkout = {
  delivery: number
  gift_card: {
    id: number | null
    amount: number
  }
  promotion: {
    id: number | null
    value: number
  }
  products: {
    id: number
    haysell_id: number
    slug: string
    discount_price: number
    quantity: number
    variation: Variation | null
    title: string
  }[]
  total: number
}
